@@ -5,8 +5,6 @@ use warnings;
 
 use File::Basename qw(basename);
 
-require 'BuildTools.recbuildtool';
-
 $ENV{'PERL5LIB'} .= ':lib';
 
 # Don't let the actual terminal size affect POD everytime we generate it.
@@ -15,11 +13,7 @@ $ENV{'PERL5LIB'} .= ':lib';
 $ENV{'COLUMNS'} = 80;
 $ENV{'LINES'}   = 50;
 
-my @scripts = BuildTools::get_bin_scripts();
-
-foreach my $script (@scripts) {
-  generate_pod("bin/$script");
-}
+generate_pod($_) for grep { not /recs-operation/ } <bin/recs-*>;
 
 sub generate_pod {
   my $script = shift;
@@ -47,17 +41,18 @@ HEADER
 
   print $fh <<FOOTER;
 
-=head1 See Also
+=head1 SEE ALSO
 
 =over
 
-=item  L<RecordStream(3)> - Overview of the scripts and the system
+=item * See L<App::RecordStream> for an overview of the scripts and the system
 
-=item  L<recs-examples(3)> - A set of simple recs examples
+=item * Run C<recs examples> or see L<App::RecordStream::Manual::Examples> for a set of simple recs examples
 
-=item  L<recs-story(3)> - A humorous introduction to RecordStream
+=item * Run C<recs story> or see L<App::RecordStream::Manual::Story> for a humorous introduction to RecordStream
 
-=item SCRIPT --help - every script has a --help option, like the output above
+=item * Every command has a C<--help> mode available to print out usage and
+examples for the particular command, just like the output above.
 
 =back
 
