@@ -1,11 +1,13 @@
 package App::RecordStream::DBHandle;
 
-our $VERSION = "4.0.7";
+our $VERSION = "4.0.11";
 
 use strict;
 use warnings;
 
-use DBI;
+use App::RecordStream::OptionalRequire 'DBI';
+BEGIN { App::RecordStream::OptionalRequire::require_done() }
+
 use Data::Dumper;
 use Getopt::Long;
 
