@@ -1,17 +1,18 @@
 package App::RecordStream::Operation::fromatomfeed;
 
-our $VERSION = "4.0.7";
+our $VERSION = "4.0.11";
 
 use strict;
 use warnings;
 
 use base qw(App::RecordStream::Operation);
 
-use LWP::UserAgent;
-use XML::Twig;
-
 use App::RecordStream::Record;
 
+use App::RecordStream::OptionalRequire 'LWP::UserAgent';
+use App::RecordStream::OptionalRequire 'XML::Twig';
+BEGIN { App::RecordStream::OptionalRequire::require_done() }
+
 sub init
 {
   my $this = shift;
