@@ -1,16 +1,17 @@
 package App::RecordStream::Operation::todb;
 
-our $VERSION = "4.0.7";
+our $VERSION = "4.0.11";
 
 use strict;
 use warnings;
 
 use base qw(App::RecordStream::Operation);
 
-use DBI;
-use Data::Dumper;
-use Tie::IxHash;
+use App::RecordStream::OptionalRequire 'DBI';
+use App::RecordStream::OptionalRequire 'Tie::IxHash';
+BEGIN { App::RecordStream::OptionalRequire::require_done() }
 
+use Data::Dumper;
 use App::RecordStream::DBHandle;
 use App::RecordStream::Record;
 
