@@ -1,6 +1,6 @@
 package App::RecordStream::Test::OperationHelper;
 
-our $VERSION = "4.0.7";
+our $VERSION = "4.0.11";
 
 use strict;
 use warnings;
@@ -8,6 +8,26 @@ use warnings;
 use Test::More;
 use App::RecordStream::InputStream;
 use App::RecordStream::OutputStream;
+use Carp qw(croak);
+
+sub import {
+  my $class = shift;
+
+  require App::RecordStream::OptionalRequire;
+  local $App::RecordStream::OptionalRequire::PRINT_WARNING = 0;
+
+  for my $op (@_) {
+    croak "invalid package name: '$op'"
+      unless $op =~ /^[a-z0-9_]+$/;
+    if (not eval "require App::RecordStream::Operation::$op; 1;") {
+      if ($@ =~ /Please install missing modules/) {
+        plan skip_all => "Missing deps for operation $op";
+      } else {
+        die $@;
+      }
+    }
+  }
+}
 
 sub new {
   my $class = shift;
@@ -96,6 +116,16 @@ sub matches {
     }
   }
 
+  # Find the call level of the originating test file for better diagnostic
+  # reporting if we fail tests below
+  my ($level_to_testfile, $file) = (0, (caller(0))[1]);
+  while (defined $file and $file !~ /\.t$/) {
+    $level_to_testfile++;
+    $file = (caller($level_to_testfile))[1];
+  }
+
+  local $Test::Builder::Level = $Test::Builder::Level + $level_to_testfile + 1;
+
   my $is_ok = 1;
   for my $record (@$results) {
     $is_ok = 0 if ( ! ok(UNIVERSAL::isa($record, 'App::RecordStream::Record'), "Record is a App::RecordStream::Record") );
